PanicAction

Enum PanicAction 

#[repr(u8)]
pub enum PanicAction { Halt = 0, Reboot = 1, }
What the kernel should do at the end of a panic

The default value should always be 0 to avoid moving structs which statically initialize this from .bss to .data

Variants



Halt = 0



Reboot = 1

Implementations

Source

impl PanicAction

pub fn from_u8(value: u8) -> Option<Self>

Construct a new PanicAction from a u8

pub fn is_valid_panic_action(value: u8) -> bool

Check if the given u8 corresponds to a valid panic action