Struct FramebufferInfo
Source pub struct FramebufferInfo {
pub addr: *mut u32,
pub pixels_per_row: u64,
pub width: u64,
pub height: u64,
pub bpp: u16,
}
Bootloader-provided info for constructing the basic framebuffer
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.