pub struct KernelSectionInfo {
pub kernel_phys_start: u64,
pub kernel_start: u64,
pub kernel_text_end: u64,
pub kernel_rodata_end: u64,
pub kernel_end: u64,
}Expand description
Virtual addresses of kernel ELF section boundaries
Fields
kernel_phys_start: u64kernel_start: u64kernel_text_end: u64This points to the byte after the last .text byte
kernel_rodata_end: u64This points to the byte after the last .rodata byte
kernel_end: u64